@@ -5,7 +5,7 @@
  *
  * Part:        Main program structure.
  *
- * Version:     $Id: main.c,v 1.1.15 2007/09/15 04:07:41 acassen Exp $
+ * Version:     $Id: main.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,11 +19,12 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2007 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include <syslog.h>
 #include "daemon.h"
+#include "logger.h"
 #include "utils.h"
 
 /* Daemonization function coming from zebra source code */
@@ -35,7 +36,7 @@ xdaemon(int nochdir, int noclose, int exitflag)
 	/* In case of fork is error. */
 	pid = fork();
 	if (pid < 0) {
-		syslog(LOG_INFO, "xdaemon: fork error");
+		log_message(LOG_INFO, "xdaemon: fork error");
 		return -1;
 	}
 
@@ -50,7 +51,7 @@ xdaemon(int nochdir, int noclose, int exitflag)
 	/* Become session leader and get pid. */
 	pid = setsid();
 	if (pid < -1) {
-		syslog(LOG_INFO, "xdaemon: setsid error");
+		log_message(LOG_INFO, "xdaemon: setsid error");
 		return -1;
 	}
 
