@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_iproute.c include file.
  *
- * Version:     $Id: vrrp_iproute.h,v 1.1.15 2007/09/15 04:07:41 acassen Exp $
+ * Version:     $Id: vrrp_iproute.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2007 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _VRRP_IPROUTE_H
@@ -39,9 +39,11 @@ typedef struct _ip_route {
 	uint32_t dst;		/* RTA_DST */
 	uint8_t dmask;
 	uint32_t gw;		/* RTA_GATEWAY */
+	uint32_t gw2;		/* Will use RTA_MULTIPATH */
 	uint32_t src;		/* RTA_PREFSRC */
 	uint32_t metric;	/* RTA_PRIORITY */
 	int index;		/* RTA_OIF */
+	int blackhole;
 	int scope;
 	int table;
 	int set;
