@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_netlink.c include file.
  *
- * Version:     $Id: vrrp_netlink.h,v 1.1.15 2007/09/15 04:07:41 acassen Exp $
+ * Version:     $Id: vrrp_netlink.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2007 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _VRRP_NETLINK_H
@@ -56,6 +56,8 @@ extern struct nl_handle nl_cmd;		/* Command channel */
 extern int addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data_obj);
 extern int addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data_obj,
 		     int alen);
+extern int rta_addattr_l(struct rtattr *rta, int maxlen, int type,
+			 const void *data, int alen);
 extern char *netlink_scope_n2a(int scope);
 extern int netlink_scope_a2n(char *scope);
 extern int netlink_socket(struct nl_handle *nl, unsigned long groups);
